diff --git a/GMW/GMW/GMW.csproj b/GMW/GMW/GMW.csproj
index dab9d6d0..42c18ca8 100644
--- a/GMW/GMW/GMW.csproj
+++ b/GMW/GMW/GMW.csproj
@@ -814,6 +814,9 @@
+
+
+
@@ -824,6 +827,9 @@
+
+
+
diff --git a/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx b/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx
index d2030c6d..e091f093 100644
--- a/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx
+++ b/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx
@@ -17,7 +17,7 @@
-
+
@@ -50,6 +50,12 @@
+
+
+
+
+
+
@@ -75,7 +81,6 @@
- <%----%>
diff --git a/GMW/GMW/bin/GMW.dll b/GMW/GMW/bin/GMW.dll
index b4adcea5..38a0507a 100644
Binary files a/GMW/GMW/bin/GMW.dll and b/GMW/GMW/bin/GMW.dll differ
diff --git a/GMW/GMW/bin/GMW_data.dll b/GMW/GMW/bin/GMW_data.dll
index dcb60eee..b5363147 100644
Binary files a/GMW/GMW/bin/GMW_data.dll and b/GMW/GMW/bin/GMW_data.dll differ
diff --git a/GMW/GMW/bin/SteamWare.dll b/GMW/GMW/bin/SteamWare.dll
index 80a43d32..ffd44baa 100644
Binary files a/GMW/GMW/bin/SteamWare.dll and b/GMW/GMW/bin/SteamWare.dll differ
diff --git a/GMW/GMW/images/approva_l.png b/GMW/GMW/images/approva_l.png
new file mode 100644
index 00000000..5da08084
Binary files /dev/null and b/GMW/GMW/images/approva_l.png differ
diff --git a/GMW/GMW/images/approva_m.png b/GMW/GMW/images/approva_m.png
new file mode 100644
index 00000000..9da598bb
Binary files /dev/null and b/GMW/GMW/images/approva_m.png differ
diff --git a/GMW/GMW/images/approva_s.png b/GMW/GMW/images/approva_s.png
new file mode 100644
index 00000000..59a0e274
Binary files /dev/null and b/GMW/GMW/images/approva_s.png differ
diff --git a/GMW/GMW/images/lista_PreFus_m.png b/GMW/GMW/images/lista_PreFus_m.png
new file mode 100644
index 00000000..ad36de4e
Binary files /dev/null and b/GMW/GMW/images/lista_PreFus_m.png differ
diff --git a/GMW/GMW/images/lista_PreFus_s.png b/GMW/GMW/images/lista_PreFus_s.png
new file mode 100644
index 00000000..334861fe
Binary files /dev/null and b/GMW/GMW/images/lista_PreFus_s.png differ
diff --git a/GMW/GMW/images/lista_preFus_l.png b/GMW/GMW/images/lista_preFus_l.png
new file mode 100644
index 00000000..44aa67a4
Binary files /dev/null and b/GMW/GMW/images/lista_preFus_l.png differ
diff --git a/GMW/GMW/obj/Debug/GMW.dll b/GMW/GMW/obj/Debug/GMW.dll
index b4adcea5..38a0507a 100644
Binary files a/GMW/GMW/obj/Debug/GMW.dll and b/GMW/GMW/obj/Debug/GMW.dll differ
diff --git a/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache b/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache
index 84b0994f..ffcddc55 100644
Binary files a/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache and b/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache differ
diff --git a/GMW/GMW_data/DS_magazzino.xss b/GMW/GMW_data/DS_magazzino.xss
index 33d20e74..8fb3355b 100644
--- a/GMW/GMW_data/DS_magazzino.xss
+++ b/GMW/GMW_data/DS_magazzino.xss
@@ -4,7 +4,7 @@
Changes to this file may cause incorrect behavior and will be lost if
the code is regenerated.
-->
-
+
@@ -16,13 +16,13 @@
-
+
-
+
-
-
-
+
+
+
diff --git a/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx.cs b/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx.cs
index d6b853fe..0cba80cf 100644
--- a/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx.cs
+++ b/GMW/GMW/WebUserControls/mod_elencoListePrelievo.ascx.cs
@@ -589,7 +589,7 @@ namespace GMW.WebUserControls
aggiornaElencoRighe();
}
///
/// restituisce URL immagine del codice da mostrare
///
///
///
@@ -598,6 +598,24 @@ namespace GMW.WebUserControls
return string.Format("~/images/circle_s_{0}.png", codStato);
}
///
+ /// restituisce URL immagine del codice da mostrare x TIPO lista
+ ///
+ ///
+ ///
+ public string pathImgTipo(object codice)
+ {
+ return string.Format("~/images/lista_{0}_s.png", codice);
+ }
+ ///
+ /// restituisce tooltip da mostrare x TIPO lista
+ ///
+ ///
+ ///
+ public string tooltipTipo(object codice)
+ {
+ return traduci(codice.ToString());
+ }
+ ///
/// mostra controllo per creare nuove liste di prelievo
///
///
@@ -589,7 +589,7 @@ namespace GMW.WebUserControls
}
///
- /// restituisce URL immagine del codice da mostrare
+ /// restituisce URL immagine del codice da mostrare x stato lista
///
///
diff --git a/GMW/GMW_data/bin/Debug/GMW_data.dll b/GMW/GMW_data/bin/Debug/GMW_data.dll
index dcb60eee..b5363147 100644
Binary files a/GMW/GMW_data/bin/Debug/GMW_data.dll and b/GMW/GMW_data/bin/Debug/GMW_data.dll differ
diff --git a/GMW/GMW_data/obj/Debug/GMW_data.dll b/GMW/GMW_data/obj/Debug/GMW_data.dll
index dcb60eee..b5363147 100644
Binary files a/GMW/GMW_data/obj/Debug/GMW_data.dll and b/GMW/GMW_data/obj/Debug/GMW_data.dll differ
diff --git a/GMW/GMW_data/obj/Debug/TempPE/DS_magazzino.Designer.cs.dll b/GMW/GMW_data/obj/Debug/TempPE/DS_magazzino.Designer.cs.dll
index fd8ea17d..a4741463 100644
Binary files a/GMW/GMW_data/obj/Debug/TempPE/DS_magazzino.Designer.cs.dll and b/GMW/GMW_data/obj/Debug/TempPE/DS_magazzino.Designer.cs.dll differ